package com.afp.ordermanagement.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.List;
import java.util.Objects;

@Data
@Builder
@AllArgsConstructor
@Document(collection = "orders")
public class Order {

    @Id
    private String id;

    private String customerId;
    private String customerEmailAddress;

    @Builder.Default
    private String orderTrackingCode = "N/A";

    private enum OrderStatus {
        RECEIVED,
        FULFILLED,
        CANCELLED
    };

    @Builder.Default
    private OrderStatus orderStatus = OrderStatus.RECEIVED;

    @Builder.Default
    private double orderCreatedAt = System.currentTimeMillis();

    @Builder.Default
    private double orderUpdatedAt = System.currentTimeMillis();

    private List<Item> orderItems;
    private CustomerAddress customerAddress;

    public Order(){
        orderStatus = OrderStatus.RECEIVED;
        orderCreatedAt = System.currentTimeMillis();
        orderUpdatedAt = System.currentTimeMillis();
        orderTrackingCode = "N/A";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof Order)) return false;
        Order order = (Order) o;
        return Double.compare(order.getOrderCreatedAt(), getOrderCreatedAt()) == 0 && Double.compare(order.getOrderUpdatedAt(), getOrderUpdatedAt()) == 0 && getId().equals(order.getId()) && getCustomerId().equals(order.getCustomerId()) && getCustomerEmailAddress().equals(order.getCustomerEmailAddress()) && Objects.equals(getOrderTrackingCode(), order.getOrderTrackingCode()) && getOrderStatus() == order.getOrderStatus() && getOrderItems().equals(order.getOrderItems()) && getCustomerAddress().equals(order.getCustomerAddress());
    }

    @Override
    public int hashCode() {
        return Objects.hash(getId(), getCustomerId(), getCustomerEmailAddress(), getOrderTrackingCode(), getOrderStatus(), getOrderCreatedAt(), getOrderUpdatedAt(), getOrderItems(), getCustomerAddress());
    }

    @Override
    public String toString() {
        return "Order{" +
                "id='" + id + '\'' +
                ", customerId='" + customerId + '\'' +
                ", customerEmailAddress='" + customerEmailAddress + '\'' +
                ", orderTrackingCode='" + orderTrackingCode + '\'' +
                ", orderStatus=" + orderStatus +
                ", orderCreatedAt=" + orderCreatedAt +
                ", orderUpdatedAt=" + orderUpdatedAt +
                ", orderItems=" + orderItems +
                ", customerAddress=" + customerAddress +
                '}';
    }
}
